( cd usr/lib ; rm -rf libgstcontrol-0.6.so )
( cd usr/lib ; ln -sf libgstcontrol-0.6.so.0.1.0 libgstcontrol-0.6.so )
( cd usr/lib ; rm -rf libgstcontrol-0.6.so.0 )
( cd usr/lib ; ln -sf libgstcontrol-0.6.so.0.1.0 libgstcontrol-0.6.so.0 )
( cd usr/lib ; rm -rf libgstreamer-0.6.so )
( cd usr/lib ; ln -sf libgstreamer-0.6.so.0.1.0 libgstreamer-0.6.so )
( cd usr/lib ; rm -rf libgstreamer-0.6.so.0 )
( cd usr/lib ; ln -sf libgstreamer-0.6.so.0.1.0 libgstreamer-0.6.so.0 )
if [ -x /usr/bin/gst-register ]; then
  /sbin/ldconfig 1> /dev/null 2> /dev/null
  /usr/bin/gst-register 1> /dev/null 2> /dev/null
fi

